API
===    

.. autosummary::
    :toctree: api/

    hisss.duel_config
    hisss.standard_config
    hisss.restricted_standard_config
    hisss.restricted_duel_config
    hisss.BattleSnakeGame
    hisss.BattleSnakeConfig
    hisss.encoding_layer_indices
    hisss.UP
    hisss.DOWN
    hisss.LEFT
    hisss.RIGHT
    hisss.BattleSnakeRewardConfig
    hisss.StandardBattleSnakeRewardConfig
    hisss.KillBattleSnakeRewardConfig
    hisss.BattleSnakeEncodingConfig
